==> pdf-model-1.6.1-sources.jar: org/verapdf/model/operator/Glyph.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.operator;
		
import org.verapdf.model.baselayer.Object;
import org.verapdf.model.coslayer.CosInteger;
import org.verapdf.model.coslayer.CosNumber;
import org.verapdf.model.coslayer.CosString;
import org.verapdf.model.coslayer.CosArray;
import org.verapdf.model.coslayer.CosName;
import org.verapdf.model.coslayer.CosDict;
import org.verapdf.model.coslayer.CosRenderingIntent;
import org.verapdf.model.coslayer.CosLang;
import org.verapdf.model.pdlayer.PDColorSpace;
import org.verapdf.model.pdlayer.PDExtGState;
import org.verapdf.model.pdlayer.PDXObject;
import org.verapdf.model.pdlayer.PDInlineImage;
import org.verapdf.model.pdlayer.PDShading;
import org.verapdf.model.pdlayer.PDFont;

		
/**  glyph used in text
 */
public interface Glyph extends Object {
	

	/**  glyph name, or empty string if the glyph is not identified by the name (as in case of CID fonts)
	 */
	public String getname();

	/**  true if the width of the glyph in the embedded font program is consistent with the width specified in the Font dictionary
	 */
	public Boolean getisWidthConsistent();

	/**  true if glyph is present in the font program
	 */
	public Boolean getisGlyphPresent();

	/**  unicode value of the glyph
	 */
	public String gettoUnicode();

	/**  value of the rendering mode at the moment the glyph is shown
	 */
	public Long getrenderingMode();
}

==> pdf-model-1.7.9-sources.jar: org/verapdf/model/operator/Glyph.java <==
package org.verapdf.model.operator;
		
import org.verapdf.model.baselayer.Object;
import org.verapdf.model.coslayer.CosInteger;
import org.verapdf.model.coslayer.CosNumber;
import org.verapdf.model.coslayer.CosString;
import org.verapdf.model.coslayer.CosArray;
import org.verapdf.model.coslayer.CosName;
import org.verapdf.model.coslayer.CosDict;
import org.verapdf.model.coslayer.CosRenderingIntent;
import org.verapdf.model.coslayer.CosLang;
import org.verapdf.model.pdlayer.PDColorSpace;
import org.verapdf.model.pdlayer.PDExtGState;
import org.verapdf.model.pdlayer.PDXObject;
import org.verapdf.model.pdlayer.PDInlineImage;
import org.verapdf.model.pdlayer.PDShading;
import org.verapdf.model.pdlayer.PDFont;

		
/**  glyph used in text
 */
public interface Glyph extends Object {
	

	/**  glyph name, or empty string if the glyph is not identified by the name (as in case of CID fonts)
	 */
	public String getname();

	/**  true if the width of the glyph in the embedded font program is consistent with the width specified in the Font dictionary
	 */
	public Boolean getisWidthConsistent();

	/**  true if glyph is present in the font program
	 */
	public Boolean getisGlyphPresent();

	/**  unicode value of the glyph
	 */
	public String gettoUnicode();

	/**  value of the rendering mode at the moment the glyph is shown
	 */
	public Long getrenderingMode();

	/**  true if toUnicode value contains codes from Unicode Private Use Area
	 */
	public Boolean getunicodePUA();

	/**  true if an ActualText entry is present for this glyph
	 */
	public Boolean getactualTextPresent();
}
